% =====================================================
%
% Solve_Two_Leakys_New
% CBP 27-12-21
% Solves two coupled leaky integrators with dynamic
% plotting on x-t and the phase plane
% ODE soln subsampled and then plotted to gain speed
%
% =====================================================

clear all;

global tau a w12 w21 p

pkg load signal
pkg load matgeom

tau = 1;

% Specify start and end times for the computation
tstart = 0;
% tend = input('Input t end');
tend = 5;
p = 0;

a = input('Input a ');
w12 = input('Input w12 ');
w21 = input('Input w21 ');

w12*w21


% Specify the initial values of the neurons
uinit = [0.0,0.1];

% Set options for the calculation - do not change
options = odeset('RelTol',1e-6,'AbsTol',1e-6,'InitialStep',tend/1e4,'MaxStep',tend/1e4);
% start the calculation - do not change
printf(" --------------- calculating ----------- \n");
[t,u] = ode45(@rhs_Two_Leakys,[tstart,tend],uinit,options);

% Get the neuron states
u1 = u(:,1);
u2 = u(:,2);

% subsample by factor 10
u1 = downsample(u1,10);
u2 = downsample(u2,10);
t = downsample(t,10);

% get mins and maxs for axis scaling
mi1 = 1.2*min(u1);
ma1 = 1.2*max(u1);
mi2 = 1.2*min(u2);
ma2 = 1.2*max(u2);
% -------------- Figure setup-------------------
f1 = figure(1);
clf(f1);
sp1 = axes(f1);
axis(sp1,[mi1,ma1,mi2,ma2]);
axis('square');
 
title(sp1,'Phase Plane');
ylabel(sp1,'u1');
xlabel(sp1,'u2');
hold(sp1);

f2 = figure(2);
clf(f2);
sp2 = axes(f2);
axis(sp2,[0,max(t),mi1,ma1]); 
  
title(sp2,'u1 - time Plot');
xlabel(sp2,'time');
ylabel(sp2,'u1');
hold(sp2);

% ---------------------------------------------
printf(" --------------- plotting ----------- \n");
i = 1;
x = 0;
y = 0;

while i < length(t) - 1

  xPrev = x;
  yPrev = y;
  y = u1(i);
  x = u2(i);
  plot(sp1,x,y,'r.','MarkerSize',20);
  plot(sp1,xPrev,yPrev,'w.','MarkerSize',20);  
  plot(sp2,t(i),y,'o');
  drawnow;
  i++;
endwhile
